@@ -1,9 +1,8 @@
 package Perl::Critic::Policy::TryTiny::RequireUse;
-
-$Perl::Critic::Policy::TryTiny::RequireUse::VERSION = '0.04';
-
+use 5.008001;
 use strict;
 use warnings;
+our $VERSION = '0.05';
 
 use Readonly;
 use Perl::Critic::Utils qw{ :severities :classification :ppi };
@@ -117,19 +116,10 @@ alternative to this policy.
 
 =back
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Aran Clary Deltac <bluefeetE<64>gmail.com>
-
-=head1 CONTRIBUTORS
-
-=over
-
-=item *
-
-Graham TerMarsch <grahamE<64>howlingfrog.com>
-
-=back
+    Aran Clary Deltac <bluefeet@gmail.com>
+    Graham TerMarsch <graham@howlingfrog.com>
 
 =head1 ACKNOWLEDGEMENTS
 
@@ -143,3 +133,5 @@ development this distribution would not exist.
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
+=cut
+
